@@ -1,3 +1,7 @@
+# Copyright 2012 django-htmlmin authors. All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 import re
 from htmlmin.minify import html_minify
 from django.conf import settings
@@ -20,7 +24,8 @@ class HtmlMinifyMiddleware(object):
         return is_request_ok and is_response_ok
 
     def process_response(self, request, response):
-        keep_comments = hasattr(settings, 'KEEP_COMMENTS_ON_MINIFYING') and settings.KEEP_COMMENTS_ON_MINIFYING
-        if self.can_minify_response(request, response):
+        minify = getattr(settings, "HTML_MINIFY", not settings.DEBUG)
+        keep_comments = getattr(settings, 'KEEP_COMMENTS_ON_MINIFYING', False)
+        if minify and self.can_minify_response(request, response):
             response.content = html_minify(response.content, ignore_comments=not keep_comments)
         return response
